'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var _extends = _interopDefault(require('@babel/runtime/helpers/extends'));
var _inheritsLoose = _interopDefault(require('@babel/runtime/helpers/inheritsLoose'));
var React = _interopDefault(require('react'));
var classNames = _interopDefault(require('classnames'));
var reactLifecyclesCompat = require('react-lifecycles-compat');

var FlashChange =
/*#__PURE__*/
function (_React$Component) {
  _inheritsLoose(FlashChange, _React$Component);

  function FlashChange() {
    var _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _React$Component.call.apply(_React$Component, [this].concat(args)) || this;
    _this.state = {
      activeFlash: false,
      props: _this.props
    };
    _this._timer = void 0;

    _this._deactivateTimer = function () {
      _this.setState({
        activeFlash: false
      });
    };

    return _this;
  }

  var _proto = FlashChange.prototype;

  _proto._activateTimer = function _activateTimer() {
    var flashDuration = this.props.flashDuration;

    if (this._deactivateTimer) {
      clearTimeout(this._deactivateTimer);
    }

    this._timer = setTimeout(this._deactivateTimer, flashDuration);
  };

  FlashChange.getDerivedStateFromProps = function getDerivedStateFromProps(nextProps, prevState) {
    var compare = nextProps.compare;
    var result = compare(prevState.props, nextProps);

    if (result) {
      return {
        activeFlash: true,
        props: nextProps
      };
    }

    return {
      props: nextProps
    };
  };

  _proto.componentDidUpdate = function componentDidUpdate(prevProps, prevState) {
    var compare = this.props.compare;
    var result = compare(prevState.props, this.state.props);

    if (result) {
      this._activateTimer();
    }
  };

  _proto.componentWillUnmount = function componentWillUnmount() {
    if (this._timer) {
      clearTimeout(this._timer);
    }
  };

  _proto.render = function render() {
    var _classNames;

    var _this$props = this.props,
        style = _this$props.style,
        className = _this$props.className,
        children = _this$props.children,
        flashClassName = _this$props.flashClassName,
        flashStyle = _this$props.flashStyle;
    var activeFlash = this.state.activeFlash;

    var styleProp = _extends({}, style);

    if (activeFlash) {
      styleProp = _extends({}, styleProp, flashStyle);
    }

    return React.createElement("div", {
      style: styleProp,
      className: classNames(className, (_classNames = {}, _classNames[flashClassName] = activeFlash, _classNames))
    }, children);
  };

  return FlashChange;
}(React.Component);

FlashChange.defaultProps = {
  flashDuration: 200,
  flashStyle: {},
  flashClassName: undefined,
  compare: function compare(prevProps, newProps) {
    return prevProps.value !== newProps.value;
  }
};
reactLifecyclesCompat.polyfill(FlashChange);

module.exports = FlashChange;
